# Generated by Django 5.1.1 on 2024-10-08 07:43

import django.utils.timezone
import uuid
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = []

    operations = [
        migrations.CreateModel(
            name="NewsletterSubscriber",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                (
                    "email",
                    models.EmailField(
                        db_comment="Unique email address used for newsletter subscription.",
                        help_text="The email address of the subscriber.",
                        max_length=254,
                        unique=True,
                        verbose_name="Email Address",
                    ),
                ),
                (
                    "date_subscribed",
                    models.DateTimeField(
                        db_comment="Timestamp of when the subscriber was added to the list.",
                        default=django.utils.timezone.now,
                        help_text="The date and time when the subscription was created.",
                        verbose_name="Date Subscribed",
                    ),
                ),
                (
                    "confirmed",
                    models.BooleanField(
                        db_comment="Boolean flag indicating confirmed subscription status.",
                        default=False,
                        help_text="Whether the subscriber has confirmed their email address.",
                        verbose_name="Confirmed Subscription",
                    ),
                ),
                (
                    "unsubscribe_token",
                    models.UUIDField(
                        db_comment="Unique token for secure unsubscribe functionality.",
                        default=uuid.uuid4,
                        editable=False,
                        help_text="A unique token used for securely unsubscribing from the newsletter.",
                        unique=True,
                        verbose_name="Unsubscribe Token",
                    ),
                ),
                (
                    "preferences",
                    models.CharField(
                        choices=[
                            ("NEWS", "News"),
                            ("DEALS", "Deals"),
                            ("TIPS", "Tips"),
                        ],
                        db_comment="Subscriber's content preference selection.",
                        default="NEWS",
                        help_text="The type of content the subscriber prefers to receive.",
                        max_length=50,
                        verbose_name="Content Preferences",
                    ),
                ),
                (
                    "frequency",
                    models.CharField(
                        choices=[
                            ("DAILY", "Daily"),
                            ("WEEKLY", "Weekly"),
                            ("MONTHLY", "Monthly"),
                        ],
                        db_comment="Subscriber's preferred frequency of newsletter delivery.",
                        default="WEEKLY",
                        help_text="How often the subscriber wishes to receive the newsletter.",
                        max_length=50,
                        verbose_name="Frequency Preferences",
                    ),
                ),
                (
                    "language",
                    models.CharField(
                        choices=[
                            ("af", "Afrikaans"),
                            ("ar", "Arabic"),
                            ("ar-dz", "Algerian Arabic"),
                            ("ast", "Asturian"),
                            ("az", "Azerbaijani"),
                            ("bg", "Bulgarian"),
                            ("be", "Belarusian"),
                            ("bn", "Bengali"),
                            ("br", "Breton"),
                            ("bs", "Bosnian"),
                            ("ca", "Catalan"),
                            ("ckb", "Central Kurdish (Sorani)"),
                            ("cs", "Czech"),
                            ("cy", "Welsh"),
                            ("da", "Danish"),
                            ("de", "German"),
                            ("dsb", "Lower Sorbian"),
                            ("el", "Greek"),
                            ("en", "English"),
                            ("en-au", "Australian English"),
                            ("en-gb", "British English"),
                            ("eo", "Esperanto"),
                            ("es", "Spanish"),
                            ("es-ar", "Argentinian Spanish"),
                            ("es-co", "Colombian Spanish"),
                            ("es-mx", "Mexican Spanish"),
                            ("es-ni", "Nicaraguan Spanish"),
                            ("es-ve", "Venezuelan Spanish"),
                            ("et", "Estonian"),
                            ("eu", "Basque"),
                            ("fa", "Persian"),
                            ("fi", "Finnish"),
                            ("fr", "French"),
                            ("fy", "Frisian"),
                            ("ga", "Irish"),
                            ("gd", "Scottish Gaelic"),
                            ("gl", "Galician"),
                            ("he", "Hebrew"),
                            ("hi", "Hindi"),
                            ("hr", "Croatian"),
                            ("hsb", "Upper Sorbian"),
                            ("hu", "Hungarian"),
                            ("hy", "Armenian"),
                            ("ia", "Interlingua"),
                            ("id", "Indonesian"),
                            ("ig", "Igbo"),
                            ("io", "Ido"),
                            ("is", "Icelandic"),
                            ("it", "Italian"),
                            ("ja", "Japanese"),
                            ("ka", "Georgian"),
                            ("kab", "Kabyle"),
                            ("kk", "Kazakh"),
                            ("km", "Khmer"),
                            ("kn", "Kannada"),
                            ("ko", "Korean"),
                            ("ky", "Kyrgyz"),
                            ("lb", "Luxembourgish"),
                            ("lt", "Lithuanian"),
                            ("lv", "Latvian"),
                            ("mk", "Macedonian"),
                            ("ml", "Malayalam"),
                            ("mn", "Mongolian"),
                            ("mr", "Marathi"),
                            ("ms", "Malay"),
                            ("my", "Burmese"),
                            ("nb", "Norwegian Bokmål"),
                            ("ne", "Nepali"),
                            ("nl", "Dutch"),
                            ("nn", "Norwegian Nynorsk"),
                            ("os", "Ossetic"),
                            ("pa", "Punjabi"),
                            ("pl", "Polish"),
                            ("pt", "Portuguese"),
                            ("pt-br", "Brazilian Portuguese"),
                            ("ro", "Romanian"),
                            ("ru", "Russian"),
                            ("sk", "Slovak"),
                            ("sl", "Slovenian"),
                            ("sq", "Albanian"),
                            ("sr", "Serbian"),
                            ("sr-latn", "Serbian Latin"),
                            ("sv", "Swedish"),
                            ("sw", "Swahili"),
                            ("ta", "Tamil"),
                            ("te", "Telugu"),
                            ("tg", "Tajik"),
                            ("th", "Thai"),
                            ("tk", "Turkmen"),
                            ("tr", "Turkish"),
                            ("tt", "Tatar"),
                            ("udm", "Udmurt"),
                            ("ug", "Uyghur"),
                            ("uk", "Ukrainian"),
                            ("ur", "Urdu"),
                            ("uz", "Uzbek"),
                            ("vi", "Vietnamese"),
                            ("zh-hans", "Simplified Chinese"),
                            ("zh-hant", "Traditional Chinese"),
                        ],
                        db_comment="Subscriber's preferred language for the newsletter.",
                        default="en-us",
                        help_text="The preferred language for the newsletter.",
                        max_length=10,
                        verbose_name="Language Preference",
                    ),
                ),
                (
                    "gdpr_consent",
                    models.BooleanField(
                        db_comment="Flag indicating GDPR consent has been given by the subscriber.",
                        default=False,
                        help_text="Whether the subscriber has given consent under GDPR.",
                        verbose_name="GDPR Consent",
                    ),
                ),
                (
                    "last_sent",
                    models.DateTimeField(
                        blank=True,
                        db_comment="Timestamp of the last newsletter sent to the subscriber.",
                        help_text="The date and time when the last newsletter was sent to this subscriber.",
                        null=True,
                        verbose_name="Last Newsletter Sent",
                    ),
                ),
                (
                    "is_active",
                    models.BooleanField(
                        db_comment="Boolean flag indicating whether the subscription is active.",
                        default=True,
                        help_text="Whether the subscription is currently active.",
                        verbose_name="Is Active",
                    ),
                ),
            ],
            options={
                "verbose_name": "Newsletter Subscriber",
                "verbose_name_plural": "Newsletter Subscribers",
                "db_table": "sage_newsletter_subscriber",
                "db_table_comment": "Table for storing newsletter subscriber information.",
            },
        ),
    ]
